Custom Storage Backends
=======================

LMCache supports integrating custom storage backends through dynamic loading or plug and play capability. This allows extending cache storage capabilities without modifying core code.

See :doc:`Storage Plugins <../../developer_guide/extending_lmcache/storage_plugins>` for more details.
